@@ -1,3 +1,18 @@
+##########################################################################
+# Copyright 2013-2021 Aerospike, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+##########################################################################
 """
 This module provides helper functions to produce dictionaries to be used with the
 :mod:`aerospike.Client.operate` and :mod:`aerospike.Client.operate_ordered` methods of the aerospike module.
@@ -659,7 +674,9 @@ def list_get_by_value_range(bin_name, return_type, value_begin, value_end, inver
     """Create a list get by value list operation.
 
     Server selects list items with a value greater than or equal to `value_begin`
-    and less than `value_end`. Server returns selected data specified by `return_type`.
+    and less than `value_end`. If `value_begin` is `None`, range is greater than or equal
+    to the first element of the list. If `value_end` is `None` range extends to the end of the list.
+    Server returns selected data specified by `return_type`.
 
     Args:
         bin_name (str): The name of the bin containing the list to fetch items from.
@@ -728,7 +745,7 @@ def list_remove_by_index_range(bin_name, index, return_type, count=None, inverte
     """Create a list remove by index range operation.
 
     The list remove by index range operation removes `count` starting at `index` and returns a value
-    specified by `return_type`
+    specified by `return_type`.
 
     Args:
         bin_name (str): The name of the bin containing the list to remove items from.
@@ -901,7 +918,10 @@ def list_remove_by_value_range(bin_name, return_type, value_begin=None,
     """Create a list remove by value range operation.
 
     Server removes list items with a value greater than or equal to `value_begin`
-    and less than `value_end`. Server returns selected data specified by `return_type`.
+    and less than `value_end`.
+    If `value_begin` is `None`, range is greater than or equal to the first element of the list.
+    If `value_end` is `None` range extends to the end of the list.
+    Server returns selected data specified by `return_type`.
 
     Args:
         bin_name (str): The name of the bin containing the list to fetch items from.
@@ -1018,6 +1038,8 @@ def list_get_by_value_rank_range_relative(bin_name, value, offset, return_type,
         bin_name (str): The name of the bin containing the list.
         value (str): The value of the item in the list for which to search
         offset (int): Begin returning items with rank == rank(found_item) + offset
+        return_type (int): Value specifying what should be returned from the operation.
+            This should be one of the :ref:`list_return_types` values 
         count (int): If specified, the number of items to return. If None,
             all items until end of list are returned.
         inverted (bool): If True, the operation is inverted, and items outside
