@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2013-2017 Aerospike, Inc.
+ * Copyright 2013-2021 Aerospike, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -52,6 +52,10 @@ extern PyObject * AerospikeClient_Exists_Invoke(
 	as_key key;
 	as_record * rec = NULL;
 
+	// For converting expressions.
+	as_exp exp_list;
+	as_exp* exp_list_p = NULL;
+
 	// For converting predexp.
 	as_predexp_list predexp_list;
 	as_predexp_list* predexp_list_p = NULL;
@@ -81,8 +85,8 @@ extern PyObject * AerospikeClient_Exists_Invoke(
 	key_initialised = true;
 
 	// Convert python policy object to as_policy_exists
-	pyobject_to_policy_read(&err, py_policy, &read_policy, &read_policy_p,
-			&self->as->config.policies.read, &predexp_list, &predexp_list_p);
+	pyobject_to_policy_read(self, &err, py_policy, &read_policy, &read_policy_p,
+			&self->as->config.policies.read, &predexp_list, &predexp_list_p, &exp_list, &exp_list_p);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
@@ -122,6 +126,10 @@ extern PyObject * AerospikeClient_Exists_Invoke(
 
 CLEANUP:
 
+	if (exp_list_p) {
+		as_exp_destroy(exp_list_p);;
+	}
+
 	if (predexp_list_p) {
 		as_predexp_list_destroy(&predexp_list);
 	}
