@@ -178,7 +178,7 @@ int check_type(AerospikeClient * self, PyObject * py_value, int op, as_error *er
 				strcmp(py_value->ob_type->tp_name, "aerospike.null")) && op == AS_OPERATOR_INCR) {
 		as_error_update(err, AEROSPIKE_ERR_PARAM, "Unsupported operand type(s) for +: only 'int' allowed");
 		return 1;
-	} else if ((!PyString_Check(py_value) && !PyUnicode_Check(py_value) && !PyByteArray_Check(py_value) &&
+	} else if ((!PyString_Check(py_value) && !PyUnicode_Check(py_value) && !PyByteArray_Check(py_value) && !PyBytes_Check(py_value) &&
 				strcmp(py_value->ob_type->tp_name, "aerospike.null")) && (op == AS_OPERATOR_APPEND || op == AS_OPERATOR_PREPEND)) {
 		as_error_update(err, AEROSPIKE_ERR_PARAM, "Cannot concatenate 'str' and 'non-str' objects");
 		return 1;
@@ -483,10 +483,7 @@ as_status add_op(AerospikeClient * self, as_error * err, PyObject * py_val, as_v
 				as_operations_add_append_str(ops, bin, val);
 				as_vector_append(unicodeStrVector, &val);
 				Py_DECREF(py_ustr1);
-			} else if (PyString_Check(py_value)) {
-				val = PyString_AsString(py_value);
-				as_operations_add_append_str(ops, bin, val);
-			} else if (PyByteArray_Check(py_value)) {
+			} else if (PyByteArray_Check(py_value) || PyBytes_Check(py_value)) {
 				as_bytes *bytes;
 				GET_BYTES_POOL(bytes, static_pool, err);
 				if (err->code == AEROSPIKE_OK) {
@@ -512,10 +509,7 @@ as_status add_op(AerospikeClient * self, as_error * err, PyObject * py_val, as_v
 				as_operations_add_prepend_str(ops, bin, val);
 				as_vector_append(unicodeStrVector, &val);
 				Py_DECREF(py_ustr1);
-			} else if (PyString_Check(py_value)) {
-				val = PyString_AsString(py_value);
-				as_operations_add_prepend_str(ops, bin, val);
-			} else if (PyByteArray_Check(py_value)) {
+			} else if (PyByteArray_Check(py_value) || PyBytes_Check(py_value)) {
 				as_bytes *bytes;
 				GET_BYTES_POOL(bytes, static_pool, err);
 				if (err->code == AEROSPIKE_OK) {
@@ -753,7 +747,11 @@ PyObject *  AerospikeClient_Operate_Invoke(
 	as_policy_operate operate_policy;
 	as_policy_operate *operate_policy_p = NULL;
 
-	// For predexp conversion.
+	// For expressions conversion.
+	as_exp exp_list;
+	as_exp* exp_list_p = NULL;
+
+	// For converting predexp.
 	as_predexp_list predexp_list;
 	as_predexp_list* predexp_list_p = NULL;
 
@@ -764,8 +762,8 @@ PyObject *  AerospikeClient_Operate_Invoke(
 	as_operations_inita(&ops, size);
 
 	if (py_policy) {
-		if(pyobject_to_policy_operate(err, py_policy, &operate_policy, &operate_policy_p,
-				&self->as->config.policies.operate, &predexp_list, &predexp_list_p) != AEROSPIKE_OK) {
+		if(pyobject_to_policy_operate(self, err, py_policy, &operate_policy, &operate_policy_p,
+				&self->as->config.policies.operate, &predexp_list, &predexp_list_p, &exp_list, &exp_list_p) != AEROSPIKE_OK) {
 			goto CLEANUP;
 		}
 	}
@@ -814,6 +812,10 @@ CLEANUP:
 		free(as_vector_get_ptr(unicodeStrVector, i));
 	}
 
+	if (exp_list_p) {
+		as_exp_destroy(exp_list_p);
+	}
+
 	if (predexp_list_p) {
 		as_predexp_list_destroy(&predexp_list);
 	}
@@ -928,7 +930,11 @@ static PyObject *  AerospikeClient_OperateOrdered_Invoke(
 	Py_ssize_t ops_list_size = PyList_Size(py_list);
 	as_operations_inita(&ops, ops_list_size);
 
-	// For predexp conversion.
+	// For expressions conversion.
+	as_exp exp_list;
+	as_exp* exp_list_p = NULL;
+
+	// For converting predexp.
 	as_predexp_list predexp_list;
 	as_predexp_list* predexp_list_p = NULL;
 
@@ -940,8 +946,8 @@ static PyObject *  AerospikeClient_OperateOrdered_Invoke(
 	CHECK_CONNECTED(err);
 
 	if (py_policy) {
-		if (pyobject_to_policy_operate(err, py_policy, &operate_policy,
-				&operate_policy_p, &self->as->config.policies.operate, &predexp_list, &predexp_list_p) != AEROSPIKE_OK) {
+		if (pyobject_to_policy_operate(self, err, py_policy, &operate_policy,
+				&operate_policy_p, &self->as->config.policies.operate, &predexp_list, &predexp_list_p, &exp_list, &exp_list_p) != AEROSPIKE_OK) {
 			goto CLEANUP;
 		}
 	}
@@ -1026,6 +1032,10 @@ CLEANUP:
 
 	as_vector_destroy(unicodeStrVector);
 
+	if (exp_list_p) {
+		as_exp_destroy(exp_list_p);
+	}
+
 	if (predexp_list_p) {
 		as_predexp_list_destroy(&predexp_list);
 	}
