@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2013-2017 Aerospike, Inc.
+ * Copyright 2013-2021 Aerospike, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -54,6 +54,10 @@ PyObject * AerospikeClient_Put_Invoke(
 	as_key key;
 	as_record rec;
 
+	// For converting predexp.
+	as_exp exp_list;
+	as_exp* exp_list_p = NULL;
+
 	// For converting predexp.
 	as_predexp_list predexp_list;
 	as_predexp_list* predexp_list_p = NULL;
@@ -97,8 +101,8 @@ PyObject * AerospikeClient_Put_Invoke(
 	}
 
 	// Convert python policy object to as_policy_write
-	pyobject_to_policy_write(&err, py_policy, &write_policy, &write_policy_p,
-			&self->as->config.policies.write, &predexp_list, &predexp_list_p);
+	pyobject_to_policy_write(self, &err, py_policy, &write_policy, &write_policy_p,
+			&self->as->config.policies.write, &predexp_list, &predexp_list_p, &exp_list, &exp_list_p);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
@@ -114,6 +118,10 @@ PyObject * AerospikeClient_Put_Invoke(
 CLEANUP:
 	POOL_DESTROY(&static_pool);
 
+	if (exp_list_p) {
+		as_exp_destroy(exp_list_p);;
+	}
+
 	if (predexp_list_p) {
 		as_predexp_list_destroy(&predexp_list);
 	}
