@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2013-2017 Aerospike, Inc.
+ * Copyright 2013-2021 Aerospike, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -240,6 +240,10 @@ PyObject * AerospikeClient_QueryApply_Invoke(
 	PyObject *py_ustr2 = NULL;
 	PyObject *py_ustr3 = NULL;
 
+	// For converting expressions.
+	as_exp exp_list;
+	as_exp* exp_list_p = NULL;
+
 	// For converting predexp.
 	as_predexp_list predexp_list;
 	as_predexp_list* predexp_list_p = NULL;
@@ -288,8 +292,8 @@ PyObject * AerospikeClient_QueryApply_Invoke(
 	is_query_init = true;
 
 	if (py_policy) {
-		pyobject_to_policy_write(&err, py_policy, &write_policy, &write_policy_p,
-				&self->as->config.policies.write, &predexp_list, &predexp_list_p);
+		pyobject_to_policy_write(self, &err, py_policy, &write_policy, &write_policy_p,
+				&self->as->config.policies.write, &predexp_list, &predexp_list_p, &exp_list, &exp_list_p);
 
 		if (err.code != AEROSPIKE_OK) {
 			goto CLEANUP;
@@ -397,6 +401,10 @@ PyObject * AerospikeClient_QueryApply_Invoke(
 	}
 
 CLEANUP:
+	if (exp_list_p) {
+		as_exp_destroy(exp_list_p);;
+	}
+
 	if (predexp_list_p) {
 		as_predexp_list_destroy(&predexp_list);
 	}
