@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2013-2017 Aerospike, Inc.
+ * Copyright 2013-2021 Aerospike, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -57,6 +57,10 @@ PyObject * AerospikeClient_Select_Invoke(
 	bool select_succeeded = false;
 	char ** bins = NULL;
 
+	// For converting expressions.
+	as_exp exp_list;
+	as_exp* exp_list_p = NULL;
+
 	// For converting predexp.
 	as_predexp_list predexp_list;
 	as_predexp_list* predexp_list_p = NULL;
@@ -135,8 +139,8 @@ PyObject * AerospikeClient_Select_Invoke(
 	}
 
 	// Convert python policy object to as_policy_exists
-	pyobject_to_policy_read(&err, py_policy, &read_policy, &read_policy_p,
-			&self->as->config.policies.read, &predexp_list, &predexp_list_p);
+	pyobject_to_policy_read(self, &err, py_policy, &read_policy, &read_policy_p,
+			&self->as->config.policies.read, &predexp_list, &predexp_list_p, &exp_list, &exp_list_p);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
@@ -155,6 +159,10 @@ PyObject * AerospikeClient_Select_Invoke(
 	}
 
 CLEANUP:
+	if (exp_list_p) {
+		as_exp_destroy(exp_list_p);;
+	}
+
 	if (predexp_list_p) {
 		as_predexp_list_destroy(&predexp_list);
 	}
