@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2013-2019 Aerospike, Inc.
+ * Copyright 2013-2021 Aerospike, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,6 +43,7 @@
 #include "serializer.h"
 #include "exceptions.h"
 #include "cdt_types.h"
+#include "cdt_operation_utils.h"
 
 #define PY_KEYT_NAMESPACE 0
 #define PY_KEYT_SET 1
@@ -56,8 +57,10 @@
 #define AS_PY_EXCEPTION_IN_DOUBT 4
 
 #define CTX_KEY "ctx"
+#define CDT_CTX_ORDER_KEY "order_key"
+#define CDT_CTX_PAD_KEY "pad_key"
 
-bool requires_int(uint64_t op);
+static bool requires_int(uint64_t op);
 
 as_status as_udf_file_to_pyobject( as_error *err, as_udf_file * entry, PyObject ** py_file )
 {
@@ -446,19 +449,8 @@ as_status pyobject_to_val(AerospikeClient * self, as_error * err, PyObject * py_
 		PyObject* py_data = PyObject_GenericGetAttr(py_obj, py_parameter);
 		Py_DECREF(py_parameter);
 		char *geo_value = PyString_AsString(AerospikeGeospatial_DoDumps(py_data, err));
-		if (aerospike_has_geo(self->as)) {
-			*val = (as_val *) as_geojson_new(geo_value, false);
-		} else {
-			as_bytes *bytes;
-			GET_BYTES_POOL(bytes, static_pool, err);
-			if (err->code == AEROSPIKE_OK) {
-				if (serialize_based_on_serializer_policy(self, serializer_type,
-					&bytes, py_data, err) != AEROSPIKE_OK) {
-					return err->code;
-				}
-				*val = (as_val *) bytes;
-			}
-		}
+		Py_DECREF(py_data);
+		*val = (as_val *) as_geojson_new(geo_value, false);
 	} else if (PyByteArray_Check(py_obj)) {
 		as_bytes *bytes;
 		GET_BYTES_POOL(bytes, static_pool, err);
@@ -601,19 +593,7 @@ as_status pyobject_to_record(AerospikeClient * self, as_error * err, PyObject *
 					geo_value = PyString_AsString(py_dumps);
 				}
 
-				if (aerospike_has_geo(self->as)) {
-					ret_val = as_record_set_geojson_strp(rec, name, strdup(geo_value), true);
-				} else {
-					as_bytes *bytes;
-					GET_BYTES_POOL(bytes, static_pool, err);
-					if (err->code == AEROSPIKE_OK) {
-						if (serialize_based_on_serializer_policy(self, serializer_type,
-							&bytes, py_data, err) != AEROSPIKE_OK) {
-							return err->code;
-						}
-						ret_val = as_record_set_bytes(rec, name, bytes);
-					}
-				}
+				ret_val = as_record_set_geojson_strp(rec, name, strdup(geo_value), true);
 				if (py_ustr != NULL) {
 					Py_DECREF(py_ustr);
 				}
@@ -785,19 +765,7 @@ as_status pyobject_to_astype_write(AerospikeClient * self, as_error * err, PyObj
 		PyObject* py_data = PyObject_GenericGetAttr(py_value, py_parameter);
 		Py_DECREF(py_parameter);
 		char *geo_value = PyString_AsString(AerospikeGeospatial_DoDumps(py_data, err));
-		if (aerospike_has_geo(self->as)) {
-			*val = (as_val *) as_geojson_new(geo_value, false);
-		} else {
-			as_bytes *bytes;
-			GET_BYTES_POOL(bytes, static_pool, err);
-			if (err->code == AEROSPIKE_OK) {
-				if (serialize_based_on_serializer_policy(self, serializer_type,
-					&bytes, py_data, err) != AEROSPIKE_OK) {
-					return err->code;
-				}
-				*val = (as_val *) bytes;
-			}
-		}
+		*val = (as_val *) as_geojson_new(geo_value, false);
 	} else if (PyByteArray_Check(py_value)) {
 		uint8_t * b = (uint8_t *) PyByteArray_AsString(py_value);
 		uint32_t z = (uint32_t) PyByteArray_Size(py_value);
@@ -1687,17 +1655,8 @@ void initialize_bin_for_strictypes(AerospikeClient *self, as_error *err, PyObjec
 	} else if (!strcmp(py_value->ob_type->tp_name, "aerospike.Geospatial")) {
 		PyObject* py_data = PyObject_GenericGetAttr(py_value, PyString_FromString("geo_data"));
 		char *geo_value = PyString_AsString(AerospikeGeospatial_DoDumps(py_data, err));
-		if (aerospike_has_geo(self->as)) {
-			as_geojson_init((as_geojson *) &binop_bin->value, geo_value, false);
-			binop_bin->valuep = &binop_bin->value;
-		} else {
-			as_bytes *bytes;
-			GET_BYTES_POOL(bytes, static_pool, err);
-			serialize_based_on_serializer_policy(self, SERIALIZER_PYTHON,
-					&bytes, py_data, err);
-			((as_val *) &binop_bin->value)->type = AS_UNKNOWN;
-			binop_bin->valuep = (as_bin_value *) bytes;
-		}
+		as_geojson_init((as_geojson *) &binop_bin->value, geo_value, false);
+		binop_bin->valuep = &binop_bin->value;
 	} else if (!strcmp(py_value->ob_type->tp_name, "aerospike.null")) {
 		((as_val *) &binop_bin->value)->type = AS_UNKNOWN;
 		binop_bin->valuep = (as_bin_value *) &as_nil;
@@ -1960,103 +1919,120 @@ string_and_pyuni_from_pystring(PyObject* py_string, PyObject** pyuni_r, char** c
 // object. This function will initilaise it, and free it IF an error occurs, otherwise, the caller must destroy
 // the as_cdt_ctx when it is done.
 as_status get_cdt_ctx(AerospikeClient* self, as_error* err, as_cdt_ctx* cdt_ctx, 
-    PyObject* op_dict, bool* ctx_in_use, as_static_pool* static_pool, int serializer_type)
+	PyObject* op_dict, bool* ctx_in_use, as_static_pool* static_pool, int serializer_type)
 {
-    PyObject* py_ctx = PyDict_GetItemString(op_dict, CTX_KEY);
-    int int_val = 0;
-    as_val* val = NULL;
+	PyObject* py_ctx = PyDict_GetItemString(op_dict, CTX_KEY);
+	long int_val = 0;
+	as_val* val = NULL;
 
-    if (!py_ctx) {
-        return AEROSPIKE_OK;
-    }
+	if (!py_ctx) {
+		return AEROSPIKE_OK;
+	}
 
-    if (PyList_Check(py_ctx)) {
-        Py_ssize_t py_list_size = PyList_Size(py_ctx);
-        as_cdt_ctx_init(cdt_ctx, (int)py_list_size);
+	if (PyList_Check(py_ctx)) {
+		Py_ssize_t py_list_size = PyList_Size(py_ctx);
+		as_cdt_ctx_init(cdt_ctx, (int)py_list_size);
 
-        for (int i = 0; i < py_list_size; i++) {
-            PyObject* py_val = PyList_GetItem(py_ctx, (Py_ssize_t)i);
+		for (int i = 0; i < py_list_size; i++) {
+			PyObject* py_val = PyList_GetItem(py_ctx, (Py_ssize_t)i);
 
-            PyObject* id_temp = PyObject_GetAttrString(py_val, "id");
-            if (PyErr_Occurred()) {
+			PyObject* id_temp = PyObject_GetAttrString(py_val, "id");
+			if (PyErr_Occurred()) {
 				as_cdt_ctx_destroy(cdt_ctx);
-                return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s", CTX_KEY);
-            }
+				return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s, id", CTX_KEY);
+			}
 
-            PyObject* value_temp = PyObject_GetAttrString(py_val, "value");
-            if (PyErr_Occurred()) {
+			PyObject* value_temp = PyObject_GetAttrString(py_val, "value");
+			if (PyErr_Occurred()) {
 				as_cdt_ctx_destroy(cdt_ctx);
-                return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s", CTX_KEY);
-            }
+				return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s, value", CTX_KEY);
+			}
 
-            uint64_t item_type = PyLong_AsUnsignedLong(id_temp);
-            if (PyErr_Occurred()) {
+			PyObject* extra_args_temp = PyObject_GetAttrString(py_val, "extra_args");
+			if (PyErr_Occurred()) {
 				as_cdt_ctx_destroy(cdt_ctx);
-                return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s", CTX_KEY);
-            }
+				return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s", CTX_KEY);
+			}
 
-            // add an as_cdt_ctx with value to cdt_ctx
-            if (requires_int(item_type)) {
-                int_val = PyLong_AsLong(value_temp);
-                if (PyErr_Occurred()) {
+			uint64_t item_type = PyLong_AsUnsignedLong(id_temp);
+			if (PyErr_Occurred()) {
+				as_cdt_ctx_destroy(cdt_ctx);
+				return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s, id to uint64_t", CTX_KEY);
+			}
+
+			// add an as_cdt_ctx with value to cdt_ctx
+			if (requires_int(item_type)) {
+				int_val = PyLong_AsLong(value_temp);
+				if (PyErr_Occurred()) {
 					as_cdt_ctx_destroy(cdt_ctx);
-                    return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s", CTX_KEY);
-                }
-                switch(item_type) {
-                    case AS_CDT_CTX_LIST_INDEX:
-                        as_cdt_ctx_add_list_index(cdt_ctx, int_val);
-                        break;
-                    case AS_CDT_CTX_LIST_RANK:
-                        as_cdt_ctx_add_list_rank(cdt_ctx, int_val);
-                        break;
-                    case AS_CDT_CTX_MAP_INDEX:
-                        as_cdt_ctx_add_map_index(cdt_ctx, int_val);
-                        break;
-                    case AS_CDT_CTX_MAP_RANK:
-                        as_cdt_ctx_add_map_rank(cdt_ctx, int_val);
-                        break;
-                    default:
+					return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s, value to long", CTX_KEY);
+				}
+				switch(item_type) {
+				case AS_CDT_CTX_LIST_INDEX:
+					as_cdt_ctx_add_list_index(cdt_ctx, int_val);
+					break;
+				case AS_CDT_CTX_LIST_RANK:
+					as_cdt_ctx_add_list_rank(cdt_ctx, int_val);
+					break;
+				case AS_CDT_CTX_MAP_INDEX:
+					as_cdt_ctx_add_map_index(cdt_ctx, int_val);
+					break;
+				case AS_CDT_CTX_MAP_RANK:
+					as_cdt_ctx_add_map_rank(cdt_ctx, int_val);
+					break;
+				case CDT_CTX_LIST_INDEX_CREATE:;
+					int list_order = 0;
+					int pad = 0;
+					get_int(err, CDT_CTX_ORDER_KEY, extra_args_temp, &list_order);
+					get_int(err, CDT_CTX_PAD_KEY, extra_args_temp, &pad);
+					as_cdt_ctx_add_list_index_create(cdt_ctx, int_val, list_order, pad);
+					break;
+				default:
+					as_cdt_ctx_destroy(cdt_ctx);
+					return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert, unknown ctx operation %s", CTX_KEY);
+				}
+			} else {
+				if (pyobject_to_val(self, err, value_temp, &val, static_pool, serializer_type) != AEROSPIKE_OK) {
+					return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s, value to as_val", CTX_KEY);
+				}
+				switch(item_type) {
+					case AS_CDT_CTX_LIST_VALUE:
+						as_cdt_ctx_add_list_value(cdt_ctx, val);
+						break;
+					case AS_CDT_CTX_MAP_KEY:
+						as_cdt_ctx_add_map_key(cdt_ctx, val);
+						break;
+					case AS_CDT_CTX_MAP_VALUE:
+						as_cdt_ctx_add_map_value(cdt_ctx, val);
+						break;
+					case CDT_CTX_MAP_KEY_CREATE:;
+						int map_order = 0;
+						get_int(err, CDT_CTX_ORDER_KEY, extra_args_temp, &map_order);
+						as_cdt_ctx_add_map_key_create(cdt_ctx, val, map_order);
+						break;
+					default:
 						as_cdt_ctx_destroy(cdt_ctx);
-                        return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert, unknown ctx operation %s", CTX_KEY);
-                }
-            } else {
-                if (pyobject_to_val(self, err, value_temp, &val, static_pool, serializer_type) != AEROSPIKE_OK) {
-                    return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s", CTX_KEY);
-                }
-                switch(item_type) {
-                    case AS_CDT_CTX_LIST_VALUE:
-                        as_cdt_ctx_add_list_value(cdt_ctx, val);
-                        break;
-                    case AS_CDT_CTX_MAP_KEY:
-                        as_cdt_ctx_add_map_key(cdt_ctx, val);
-                        break;
-                    case AS_CDT_CTX_MAP_VALUE:
-                        as_cdt_ctx_add_map_value(cdt_ctx, val);
-                        break;
-                    default:
-						as_cdt_ctx_destroy(cdt_ctx);
-                        return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert, unknown ctx operation %s", CTX_KEY);
-                }
-            }
+						return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert, unknown ctx operation %s", CTX_KEY);
+				}
+			}
 
-            Py_DECREF(id_temp);
-            Py_DECREF(value_temp);
-        }
-    }
-    else {
-        return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s", CTX_KEY);
-    }
+			Py_DECREF(id_temp);
+			Py_DECREF(value_temp);
+		}
+	}
+	else {
+		return as_error_update(err, AEROSPIKE_ERR_PARAM, "Failed to convert %s", CTX_KEY);
+	}
 
 	*ctx_in_use = true;
 	return AEROSPIKE_OK;
 }
 
-bool
-requires_int(uint64_t op) {
-    return(
-        op == AS_CDT_CTX_LIST_INDEX ||
-        op == AS_CDT_CTX_LIST_RANK  ||
-        op == AS_CDT_CTX_MAP_INDEX  ||
-        op == AS_CDT_CTX_MAP_RANK
-    );
+static bool requires_int(uint64_t op) {
+	return
+		op == AS_CDT_CTX_LIST_INDEX ||
+		op == AS_CDT_CTX_LIST_RANK  ||
+		op == AS_CDT_CTX_MAP_INDEX  ||
+		op == AS_CDT_CTX_MAP_RANK   ||
+		op == CDT_CTX_LIST_INDEX_CREATE;
 }
\ No newline at end of file
