@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2013-2019 Aerospike, Inc.
+ * Copyright 2013-2021 Aerospike, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -40,13 +40,13 @@ PyObject * AerospikeException_New(void)
 		{&exceptions_array.InvalidRequest, &exceptions_array.ServerFull, &exceptions_array.AlwaysForbidden,
 			&exceptions_array.UnsupportedFeature, &exceptions_array.DeviceOverload, &exceptions_array.NamespaceNotFound, 
 			&exceptions_array.ForbiddenError, &exceptions_array.QueryError, &exceptions_array.ClusterError, 
-			&exceptions_array.InvalidGeoJSON, &exceptions_array.OpNotApplicable, &exceptions_array.FilteredOut},
+			&exceptions_array.InvalidGeoJSON, &exceptions_array.OpNotApplicable, &exceptions_array.FilteredOut, &exceptions_array.LostConflict},
 		{"InvalidRequest", "ServerFull", "AlwaysForbidden", "UnsupportedFeature", "DeviceOverload", "NamespaceNotFound",
-			"ForbiddenError", "QueryError", "ClusterError", "InvalidGeoJSON", "OpNotApplicable", "FilteredOut"},
+			"ForbiddenError", "QueryError", "ClusterError", "InvalidGeoJSON", "OpNotApplicable", "FilteredOut", "LostConflict"},
 		{AEROSPIKE_ERR_REQUEST_INVALID, AEROSPIKE_ERR_SERVER_FULL, AEROSPIKE_ERR_ALWAYS_FORBIDDEN,
 			AEROSPIKE_ERR_UNSUPPORTED_FEATURE, AEROSPIKE_ERR_DEVICE_OVERLOAD, AEROSPIKE_ERR_NAMESPACE_NOT_FOUND,  
 			AEROSPIKE_ERR_FAIL_FORBIDDEN, AEROSPIKE_ERR_QUERY, AEROSPIKE_ERR_CLUSTER, AEROSPIKE_ERR_GEO_INVALID_GEOJSON,
-			AEROSPIKE_ERR_OP_NOT_APPLICABLE, AEROSPIKE_FILTERED_OUT}
+			AEROSPIKE_ERR_OP_NOT_APPLICABLE, AEROSPIKE_FILTERED_OUT, AEROSPIKE_LOST_CONFLICT}
 	};
 
 	struct record_exceptions_struct record_array = { 
