@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2013-2019 Aerospike, Inc.
+ * Copyright 2013-2021 Aerospike, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,13 +18,14 @@
 #include <stdbool.h>
 
 #include <aerospike/as_error.h>
+#include <aerospike/as_exp.h>
+#include <aerospike/as_predexp.h>
 #include <aerospike/as_policy.h>
 #include <aerospike/as_record.h>
 #include <aerospike/as_status.h>
 #include <aerospike/as_admin.h>
 #include <aerospike/as_operations.h>
 #include <aerospike/aerospike_index.h>
-#include <aerospike/as_predexp.h>
 #include "aerospike/as_scan.h"
 #include "aerospike/as_job.h"
 
@@ -72,10 +73,25 @@ __policy##_init(policy);\
 	}\
 }
 
+#define POLICY_SET_EXPRESSIONS_BASE_FIELD() {\
+	if (exp_list) {\
+		PyObject* py_exp_list = PyDict_GetItemString(py_policy, "expressions");\
+		if (py_exp_list) {\
+			if (convert_exp_list(self, py_exp_list, &exp_list, err) == AEROSPIKE_OK) {\
+				policy->base.filter_exp = exp_list;\
+				*exp_list_p = exp_list;\
+			}\
+		}\
+	}\
+}
+
 #define POLICY_SET_PREDEXP_BASE_FIELD() {\
 	if (predexp_list) {\
 		PyObject* py_predexp_list = PyDict_GetItemString(py_policy, "predexp");\
 		if (py_predexp_list) {\
+			if (PyDict_GetItemString(py_policy, "expressions")) {\
+				return as_error_update(err, AEROSPIKE_ERR_PARAM, "Got both predexp and expressions, can only handle one or the other.");\
+			}\
 			long number_predexp = PyList_Size(py_predexp_list);\
 			as_predexp_list_init(predexp_list, number_predexp);\
 			convert_predexp_list(py_predexp_list, predexp_list, err);\
@@ -206,8 +222,8 @@ AerospikeConstants aerospike_constants[] = {
 	{ OP_MAP_GET_BY_INDEX_RANGE             ,   "OP_MAP_GET_BY_INDEX_RANGE"},
 	{ OP_MAP_GET_BY_RANK                    ,   "OP_MAP_GET_BY_RANK"},
 	{ OP_MAP_GET_BY_RANK_RANGE              ,   "OP_MAP_GET_BY_RANK_RANGE"},
-	{ OP_MAP_GET_BY_VALUE_LIST, "OP_MAP_GET_BY_VALUE_LIST"},
-	{ OP_MAP_GET_BY_KEY_LIST, "OP_MAP_GET_BY_KEY_LIST" },
+	{ OP_MAP_GET_BY_VALUE_LIST              ,   "OP_MAP_GET_BY_VALUE_LIST"},
+	{ OP_MAP_GET_BY_KEY_LIST                ,   "OP_MAP_GET_BY_KEY_LIST" },
 
 	{ AS_MAP_UNORDERED                      ,   "MAP_UNORDERED"},
 	{ AS_MAP_KEY_ORDERED                    ,   "MAP_KEY_ORDERED"},
@@ -265,11 +281,22 @@ AerospikeConstants aerospike_constants[] = {
 	{AS_LIST_UNORDERED, "LIST_UNORDERED"},
 	{OP_LIST_REMOVE_BY_VALUE_RANK_RANGE_REL, "OP_LIST_REMOVE_BY_VALUE_RANK_RANGE_REL"},
 	{OP_LIST_GET_BY_VALUE_RANK_RANGE_REL, "OP_LIST_GET_BY_VALUE_RANK_RANGE_REL"},
+
+	/* CDT operations for use with expressions, new in 5.0 */
 	{OP_MAP_REMOVE_BY_VALUE_RANK_RANGE_REL, "OP_MAP_REMOVE_BY_VALUE_RANK_RANGE_REL"},
 	{OP_MAP_REMOVE_BY_KEY_INDEX_RANGE_REL, "OP_MAP_REMOVE_BY_KEY_INDEX_RANGE_REL"},
 	{OP_MAP_GET_BY_VALUE_RANK_RANGE_REL, "OP_MAP_GET_BY_VALUE_RANK_RANGE_REL"},
 	{OP_MAP_GET_BY_KEY_INDEX_RANGE_REL, "OP_MAP_GET_BY_KEY_INDEX_RANGE_REL" },
 
+	{OP_LIST_GET_BY_VALUE_RANK_RANGE_REL_TO_END, "OP_LIST_GET_BY_VALUE_RANK_RANGE_REL_TO_END"},
+	{OP_LIST_GET_BY_INDEX_RANGE_TO_END, "OP_LIST_GET_BY_INDEX_RANGE_TO_END"},
+	{OP_LIST_GET_BY_RANK_RANGE_TO_END, "OP_LIST_GET_BY_RANK_RANGE_TO_END"},
+	{OP_LIST_REMOVE_BY_REL_RANK_RANGE_TO_END, "OP_LIST_REMOVE_BY_REL_RANK_RANGE_TO_END"},
+	{OP_LIST_REMOVE_BY_REL_RANK_RANGE, "OP_LIST_REMOVE_BY_REL_RANK_RANGE"},
+	{OP_LIST_REMOVE_BY_INDEX_RANGE_TO_END, "OP_LIST_REMOVE_BY_INDEX_RANGE_TO_END"},
+	{OP_LIST_REMOVE_BY_RANK_RANGE_TO_END, "OP_LIST_REMOVE_BY_RANK_RANGE_TO_END"},
+	
+
 	{ AS_MAP_WRITE_NO_FAIL, "MAP_WRITE_NO_FAIL"},
 	{ AS_MAP_WRITE_PARTIAL, "MAP_WRITE_PARTIAL"},
 
@@ -334,10 +361,12 @@ AerospikeConstants aerospike_constants[] = {
 	{ AS_CDT_CTX_LIST_INDEX, "CDT_CTX_LIST_INDEX"},
 	{ AS_CDT_CTX_LIST_RANK, "CDT_CTX_LIST_RANK"},
 	{ AS_CDT_CTX_LIST_VALUE, "CDT_CTX_LIST_VALUE"},
+	{ CDT_CTX_LIST_INDEX_CREATE, "CDT_CTX_LIST_INDEX_CREATE"},
 	{ AS_CDT_CTX_MAP_INDEX, "CDT_CTX_MAP_INDEX"},
 	{ AS_CDT_CTX_MAP_RANK, "CDT_CTX_MAP_RANK"},
 	{ AS_CDT_CTX_MAP_KEY, "CDT_CTX_MAP_KEY"},
 	{ AS_CDT_CTX_MAP_VALUE, "CDT_CTX_MAP_VALUE"},
+	{ CDT_CTX_MAP_KEY_CREATE, "CDT_CTX_MAP_KEY_CREATE"},
 
 	/* HLL constants 3.11.0 */
 	{ OP_HLL_ADD, "OP_HLL_ADD"},
@@ -352,6 +381,7 @@ AerospikeConstants aerospike_constants[] = {
 	{ OP_HLL_INIT, "OP_HLL_INIT"},
 	{ OP_HLL_REFRESH_COUNT, "OP_HLL_REFRESH_COUNT"},
 	{ OP_HLL_SET_UNION, "OP_HLL_SET_UNION"},
+	{ OP_HLL_MAY_CONTAIN, "OP_HLL_MAY_CONTAIN"}, // for expression filters
 
 	{ AS_HLL_WRITE_DEFAULT, "HLL_WRITE_DEFAULT"},
 	{ AS_HLL_WRITE_CREATE_ONLY, "HLL_WRITE_CREATE_ONLY"},
@@ -359,6 +389,36 @@ AerospikeConstants aerospike_constants[] = {
 	{ AS_HLL_WRITE_NO_FAIL, "HLL_WRITE_NO_FAIL"},
 	{ AS_HLL_WRITE_ALLOW_FOLD, "HLL_WRITE_ALLOW_FOLD"},
 
+	{ OP_MAP_REMOVE_BY_KEY_REL_INDEX_RANGE_TO_END, "OP_MAP_REMOVE_BY_KEY_REL_INDEX_RANGE_TO_END"},
+	{ OP_MAP_REMOVE_BY_VALUE_REL_RANK_RANGE_TO_END, "OP_MAP_REMOVE_BY_VALUE_REL_RANK_RANGE_TO_END"},
+	{ OP_MAP_REMOVE_BY_INDEX_RANGE_TO_END, "OP_MAP_REMOVE_BY_INDEX_RANGE_TO_END"},
+	{ OP_MAP_REMOVE_BY_RANK_RANGE_TO_END, "OP_MAP_REMOVE_BY_RANK_RANGE_TO_END"},
+	{ OP_MAP_GET_BY_KEY_REL_INDEX_RANGE_TO_END, "OP_MAP_GET_BY_KEY_REL_INDEX_RANGE_TO_END"},
+	{ OP_MAP_REMOVE_BY_KEY_REL_INDEX_RANGE, "OP_MAP_REMOVE_BY_KEY_REL_INDEX_RANGE"},
+	{ OP_MAP_REMOVE_BY_VALUE_REL_INDEX_RANGE, "OP_MAP_REMOVE_BY_VALUE_REL_INDEX_RANGE"},
+	{ OP_MAP_REMOVE_BY_VALUE_REL_RANK_RANGE, "OP_MAP_REMOVE_BY_VALUE_REL_RANK_RANGE"},
+	{ OP_MAP_GET_BY_KEY_REL_INDEX_RANGE, "OP_MAP_GET_BY_KEY_REL_INDEX_RANGE"},
+	{ OP_MAP_GET_BY_VALUE_RANK_RANGE_REL_TO_END, "OP_MAP_GET_BY_VALUE_RANK_RANGE_REL_TO_END"},
+	{ OP_MAP_GET_BY_INDEX_RANGE_TO_END, "OP_MAP_GET_BY_INDEX_RANGE_TO_END"},
+	{ OP_MAP_GET_BY_RANK_RANGE_TO_END, "OP_MAP_GET_BY_RANK_RANGE_TO_END"},
+
+	/* For BinType expression, as_bytes_type */
+	{ AS_BYTES_UNDEF, "AS_BYTES_UNDEF"},
+	{ AS_BYTES_INTEGER, "AS_BYTES_INTEGER"},
+	{ AS_BYTES_DOUBLE, "AS_BYTES_DOUBLE"},
+	{ AS_BYTES_STRING, "AS_BYTES_STRING"},
+	{ AS_BYTES_BLOB, "AS_BYTES_BLOB"},
+	{ AS_BYTES_JAVA, "AS_BYTES_JAVA"},
+	{ AS_BYTES_CSHARP, "AS_BYTES_CSHARP"},
+	{ AS_BYTES_PYTHON, "AS_BYTES_PYTHON"},
+	{ AS_BYTES_RUBY, "AS_BYTES_RUBY"},
+	{ AS_BYTES_PHP, "AS_BYTES_PHP"},
+	{ AS_BYTES_ERLANG, "AS_BYTES_ERLANG"},
+	{ AS_BYTES_HLL, "AS_BYTES_HLL"},
+	{ AS_BYTES_MAP, "AS_BYTES_MAP"},
+	{ AS_BYTES_LIST, "AS_BYTES_LIST"},
+	{ AS_BYTES_GEOJSON, "AS_BYTES_GEOJSON"},
+	{ AS_BYTES_TYPE_MAX, "AS_BYTES_TYPE_MAX"}
 };
 
 static
@@ -500,7 +560,7 @@ exit:
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
  */
-as_status pyobject_to_policy_admin(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_admin(AerospikeClient * self, as_error * err, PyObject * py_policy, // remove self
 		as_policy_admin * policy,
 		as_policy_admin ** policy_p,
 		as_policy_admin * config_admin_policy)
@@ -527,12 +587,14 @@ as_status pyobject_to_policy_admin(as_error * err, PyObject * py_policy,
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
  */
-as_status pyobject_to_policy_apply(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_apply(AerospikeClient * self, as_error * err, PyObject * py_policy,
 		as_policy_apply * policy,
 		as_policy_apply ** policy_p,
 		as_policy_apply * config_apply_policy,
 		as_predexp_list * predexp_list,
-		as_predexp_list ** predexp_list_p)
+		as_predexp_list ** predexp_list_p,
+		as_exp * exp_list,
+		as_exp ** exp_list_p)
 {
 	// Initialize Policy
 	POLICY_INIT(as_policy_apply);
@@ -551,13 +613,16 @@ as_status pyobject_to_policy_apply(as_error * err, PyObject * py_policy,
 
 	POLICY_SET_FIELD(key, as_policy_key);
 	POLICY_SET_FIELD(replica, as_policy_replica);
-	POLICY_SET_FIELD(gen, as_policy_gen);
+	//POLICY_SET_FIELD(gen, as_policy_gen); removed
 	POLICY_SET_FIELD(commit_level, as_policy_commit_level);
 	POLICY_SET_FIELD(durable_delete, bool);
 
 	// C client 4.6.7 new policy
 	POLICY_SET_PREDEXP_BASE_FIELD();
 
+	// C client 5.0 new expressions
+	POLICY_SET_EXPRESSIONS_BASE_FIELD();
+
 	// Update the policy
 	POLICY_UPDATE();
 
@@ -597,14 +662,16 @@ as_status pyobject_to_policy_info(as_error * err, PyObject * py_policy,
  * Returns AEROSPIKE_OK on success. On error, the err argument is populated.
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
- * predexp_list is initialized by this function, caller must free.
+ * exp_list, predexp_list are initialized by this function, caller must free.
  */
-as_status pyobject_to_policy_query(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_query(AerospikeClient * self, as_error * err, PyObject * py_policy,
 		as_policy_query * policy,
 		as_policy_query ** policy_p,
 		as_policy_query * config_query_policy,
 		as_predexp_list * predexp_list,
-		as_predexp_list ** predexp_list_p)
+		as_predexp_list ** predexp_list_p,
+		as_exp * exp_list,
+		as_exp ** exp_list_p)
 {
 	// Initialize Policy
 	POLICY_INIT(as_policy_query);
@@ -627,6 +694,9 @@ as_status pyobject_to_policy_query(as_error * err, PyObject * py_policy,
 	// C client 4.6.7 new policy
 	POLICY_SET_PREDEXP_BASE_FIELD();
 
+	// C client 5.0 new expressions
+	POLICY_SET_EXPRESSIONS_BASE_FIELD();
+
 	// Update the policy
 	POLICY_UPDATE();
 
@@ -639,12 +709,14 @@ as_status pyobject_to_policy_query(as_error * err, PyObject * py_policy,
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
  */
-as_status pyobject_to_policy_read(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_read(AerospikeClient * self, as_error * err, PyObject * py_policy,
 		as_policy_read * policy,
 		as_policy_read ** policy_p,
 		as_policy_read * config_read_policy,
 		as_predexp_list * predexp_list,
-		as_predexp_list ** predexp_list_p)
+		as_predexp_list ** predexp_list_p,
+		as_exp * exp_list,
+		as_exp ** exp_list_p)
 {
 	// Initialize Policy
 	POLICY_INIT(as_policy_read);
@@ -672,6 +744,9 @@ as_status pyobject_to_policy_read(as_error * err, PyObject * py_policy,
 	// C client 4.6.7 new policy
 	POLICY_SET_PREDEXP_BASE_FIELD();
 
+	// C client 5.0 new expressions
+	POLICY_SET_EXPRESSIONS_BASE_FIELD();
+
 	// Update the policy
 	POLICY_UPDATE();
 
@@ -684,12 +759,14 @@ as_status pyobject_to_policy_read(as_error * err, PyObject * py_policy,
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
  */
-as_status pyobject_to_policy_remove(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_remove(AerospikeClient * self, as_error * err, PyObject * py_policy,
 		as_policy_remove * policy,
 		as_policy_remove ** policy_p,
 		as_policy_remove * config_remove_policy,
 		as_predexp_list * predexp_list,
-		as_predexp_list ** predexp_list_p)
+		as_predexp_list ** predexp_list_p,
+		as_exp * exp_list,
+		as_exp ** exp_list_p)
 {
 	// Initialize Policy
 	POLICY_INIT(as_policy_remove);
@@ -717,6 +794,9 @@ as_status pyobject_to_policy_remove(as_error * err, PyObject * py_policy,
 	// C client 4.6.7 new policy
 	POLICY_SET_PREDEXP_BASE_FIELD();
 
+	// C client 5.0 new expressions
+	POLICY_SET_EXPRESSIONS_BASE_FIELD();
+
 	// Update the policy
 	POLICY_UPDATE();
 
@@ -729,12 +809,14 @@ as_status pyobject_to_policy_remove(as_error * err, PyObject * py_policy,
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
  */
-as_status pyobject_to_policy_scan(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_scan(AerospikeClient * self, as_error * err, PyObject * py_policy,
 		as_policy_scan * policy,
 		as_policy_scan ** policy_p,
 		as_policy_scan * config_scan_policy,
 		as_predexp_list * predexp_list,
-		as_predexp_list ** predexp_list_p)
+		as_predexp_list ** predexp_list_p,
+		as_exp * exp_list,
+		as_exp ** exp_list_p)
 {
 	// Initialize Policy
 	POLICY_INIT(as_policy_scan);
@@ -759,6 +841,9 @@ as_status pyobject_to_policy_scan(as_error * err, PyObject * py_policy,
 	// C client 4.6.7 new policy
 	POLICY_SET_PREDEXP_BASE_FIELD();
 
+	// C client 5.0 new expressions
+	POLICY_SET_EXPRESSIONS_BASE_FIELD();
+
 	// Update the policy
 	POLICY_UPDATE();
 
@@ -771,12 +856,14 @@ as_status pyobject_to_policy_scan(as_error * err, PyObject * py_policy,
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
  */
-as_status pyobject_to_policy_write(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_write(AerospikeClient * self, as_error * err, PyObject * py_policy,
 		as_policy_write * policy,
 		as_policy_write ** policy_p,
 		as_policy_write * config_write_policy,
 		as_predexp_list * predexp_list,
-		as_predexp_list ** predexp_list_p)
+		as_predexp_list ** predexp_list_p,
+		as_exp * exp_list,
+		as_exp ** exp_list_p)
 {
 	// Initialize Policy
 	POLICY_INIT(as_policy_write);
@@ -805,6 +892,9 @@ as_status pyobject_to_policy_write(as_error * err, PyObject * py_policy,
 	// C client 4.6.7 new policy
 	POLICY_SET_PREDEXP_BASE_FIELD();
 
+	// C client 5.0 new expressions
+	POLICY_SET_EXPRESSIONS_BASE_FIELD();
+
 	// Update the policy
 	POLICY_UPDATE();
 
@@ -817,12 +907,14 @@ as_status pyobject_to_policy_write(as_error * err, PyObject * py_policy,
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
  */
-as_status pyobject_to_policy_operate(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_operate(AerospikeClient * self, as_error * err, PyObject * py_policy,
 		as_policy_operate * policy,
 		as_policy_operate ** policy_p,
 		as_policy_operate * config_operate_policy,
 		as_predexp_list * predexp_list,
-		as_predexp_list ** predexp_list_p)
+		as_predexp_list ** predexp_list_p,
+		as_exp * exp_list,
+		as_exp ** exp_list_p)
 {
 	// Initialize Policy
 	POLICY_INIT(as_policy_operate);
@@ -854,6 +946,9 @@ as_status pyobject_to_policy_operate(as_error * err, PyObject * py_policy,
 	// C client 4.6.7 new policy
 	POLICY_SET_PREDEXP_BASE_FIELD();
 
+	// C client 5.0 new expressions
+	POLICY_SET_EXPRESSIONS_BASE_FIELD();
+
 	// Update the policy
 	POLICY_UPDATE();
 
@@ -866,12 +961,14 @@ as_status pyobject_to_policy_operate(as_error * err, PyObject * py_policy,
  * We assume that the error object and the policy object are already allocated
  * and initialized (although, we do reset the error object here).
  */
-as_status pyobject_to_policy_batch(as_error * err, PyObject * py_policy,
+as_status pyobject_to_policy_batch(AerospikeClient * self, as_error * err, PyObject * py_policy,
 		as_policy_batch * policy,
 		as_policy_batch ** policy_p,
 		as_policy_batch * config_batch_policy,
 		as_predexp_list * predexp_list,
-		as_predexp_list ** predexp_list_p)
+		as_predexp_list ** predexp_list_p,
+		as_exp * exp_list,
+		as_exp ** exp_list_p)
 {
 	// Initialize Policy
 	POLICY_INIT(as_policy_batch);
@@ -901,6 +998,9 @@ as_status pyobject_to_policy_batch(as_error * err, PyObject * py_policy,
 	// C client 4.6.7 new policy
 	POLICY_SET_PREDEXP_BASE_FIELD();
 
+	// C client 5.0 new expressions
+	POLICY_SET_EXPRESSIONS_BASE_FIELD();
+
 	// Update the policy
 	POLICY_UPDATE();
 
